@@ -3,13 +3,13 @@
 
 
 """
-   pycount.pycount
+   pycount.core
    ~~~~~~~~~~~~~~~
 
    Core pycount file
 
    :copyright: (c) Tihomir Saulic
-   :license: DO WHAT YOU WANT TO PUBLIC LICENSE, see LICENSE for more details
+   :license: MIT License, see LICENSE for more details
 """
 
 
@@ -21,6 +21,7 @@ import re
 import sys
 import time
 
+from pycount.exceptions import InvalidIgnoreTypeError
 from pycount.patterns import FILE_TYPE_PATTERNS
 from pycount.patterns import COMMENT_PATTERNS
 from pycount.patterns import BY_FILES_PATTERNS
@@ -54,7 +55,7 @@ def exact_match(phrase, word):
 def isfile(obj):
     """Check whether a file or not
     """
-    if type(obj) is str and os.path.isfile(obj):
+    if isinstance(obj, str) and os.path.isfile(obj):
         return True
 
 
@@ -78,7 +79,7 @@ class Timer(object):
 class Counter(object):
     """Main clas for counting the lines of code
     """
-    def __init__(self, root=None, patterns=None, by_files=None):
+    def __init__(self, root=None, patterns=None, by_files=None, ignore=None):
         if root is None:
             self.root = os.getcwd()
         else:
@@ -100,7 +101,18 @@ class Counter(object):
         else:
             self.by_files = by_files
 
-        self.ignore = IGNORE_PATTERNS
+        if ignore is None:
+            self.ignore = IGNORE_PATTERNS
+        else:
+            new_ignore_list = []
+            if isinstance(ignore, list):
+                for ipath in ignore:
+                    new_ignore_list.append(ipath)
+            elif isinstance(ignore, str):
+                new_ignore_list.append(ignore)
+            else:
+                raise InvalidIgnoreTypeError("Must use 'str' or 'list' type")
+            self.ignore = IGNORE_PATTERNS + new_ignore_list
 
         self.comment_patterns = COMMENT_PATTERNS
 
@@ -121,22 +133,19 @@ class Counter(object):
             return unique
 
     def walker(self, fpath=None, a_file=None):
-        """Takes care of finding actual files that need to be added to the
+        """Takes care of finding actual files that need to be added to
            self.files
         """
         def valid_entry(entry):
             """Detects whether an entry is unique, has data and discards it
-               if it's a binary file or a symbolic link.
+               if it's a binary file or a symbolic link
             """
             try:
                 has_data = os.stat(entry).st_size > 0
             except OSError:
                 has_data = False
-            if has_data and self.unique(entry) and not is_binary(entry) \
-                    and not os.path.islink(entry):
-                return True
-            else:
-                return False
+            return bool(has_data and self.unique(entry) and \
+                not is_binary(entry) and not os.path.islink(entry))
         if a_file is not None and valid_entry(a_file):
             self.files.append(a_file)
         if fpath is not None:
@@ -144,6 +153,8 @@ class Counter(object):
                 for pattern in self.ignore:
                     if pattern in subpaths:
                         subpaths.remove(pattern)
+                    if pattern in files:
+                        files.remove(pattern)
                 for a_file in files:
                     for entry in self.by_files.keys():
                         if exact_match(a_file, entry):
@@ -173,15 +184,26 @@ class Counter(object):
         self.files = []
         self.hashes = {}
 
-        for fpath in self.root:
-            if isfile(fpath):
-                self.walker(a_file=fpath)
-            elif os.path.exists(fpath) and not os.path.isfile(fpath):
-                self.walker(fpath=fpath)
-            else:
-                print("Invalid path specified: %s" % fpath)
+        if isinstance(self.root, str) and isfile(self.root):
+            self.walker(a_file=self.root)
+        elif isinstance(self.root, str) and not isfile(self.root):
+            self.walker(fpath=self.root)
+        elif isinstance(self.root, list):
+            for fpath in self.root:
+                if isfile(fpath):
+                    self.walker(a_file=fpath)
+                elif os.path.exists(fpath) and not os.path.isfile(fpath):
+                    self.walker(fpath=fpath)
+                else:
+                    print("Invalid path specified: %s" % fpath)
         self.total_uniques = len(self.files)
-        print(str(self.total_uniques) + " unique files")
+        if self.total_uniques > 1:
+            print(str(self.total_uniques) + " unique files")
+        else:
+            print(str(self.total_uniques) + " unique file")
+
+    def is_comment(self, line, extension):
+        pass
 
     def count(self):
         """Counts lines of code for valid files in self.patterns
@@ -215,7 +237,7 @@ class Counter(object):
                 except KeyError:
                     self.results[self.by_files[fname]] = 0
                     self.results[self.by_files[fname]] += count
-            if ext in self.patterns.keys():
+            elif ext in self.patterns.keys():
                 with open(fpath, "rb") as a_file:
                     for line in a_file:
                         if line.strip():
